<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_TrustpilotInvitationApi
 * @copyright   Copyright (c) 2020 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Mohamed Zahran <zahran@pinpointdesigns.co.uk>
 */

namespace Trustpilot\Api\Invitation;

use GuzzleHttp\Exception\GuzzleException;

/**
 * Class ServiceReview
 * @package Trustpilot\Api\Invitation
 */
class ServiceReview
{
    /**
     * @var string
     */
    protected $apiKey;

    /**
     * @var \GuzzleHttp\Client
     */
    protected $guzzle;

    /**
     * ServiceReview constructor.
     * @param string $apiKey
     * @param \GuzzleHttp\Client|null $guzzle
     * @param \Logger|null $logger
     */
    public function __construct(
        string $apiKey,
        \GuzzleHttp\Client $guzzle = null,
        \Logger $logger = null
    ) {
        $this->apiKey = $apiKey;
        $this->guzzle = $guzzle ?? new \GuzzleHttp\Client();
    }

    /**
     * @param int $count
     * @param array $state
     * @param string $language
     * @return mixed
     * @throws GuzzleException
     */
    public function getLatest(
        int $count = 20,
        array $state = ['published'],
        string $language = 'en'
    ) {
        $query = [
            'apikey' => $this->apiKey,
            'count' => $count,
            'language' => $language,
            'state' => implode(',', $state),
        ];

        $method = 'GET';

        $url = \Trustpilot\Api\Invitation\Client::API_ENDPOINT . '/reviews/latest';

        $response = $this->guzzle->request(
            $method,
            $url,
            \compact('query')
        );

        return json_decode((string) $response->getBody(), true);
    }
}
